@@ -6,7 +6,7 @@
 # David Hunter <dhunter@stat.psu.edu> and Mark S. Handcock
 # <handcock@u.washington.edu>.
 #
-# Last Modified 09/05/10
+# Last Modified 01/27/11
 # Licensed under the GNU General Public License version 2 (June, 1991)
 #
 # Part of the R/network package
@@ -63,7 +63,13 @@ add.edge<-function(x, tail, head, names.eval=NULL, vals.eval=NULL, edge.check=FA
   if(!is.network(x))
     stop("add.edge requires an argument of class network.")
   #Do the deed
-  invisible(.Call("addEdge_R",x,tail,head,names.eval,vals.eval,edge.check, PACKAGE="network"))
+  xn<-deparse(substitute(x))
+  ev<-parent.frame()
+  x$RIsTooLazy<-NULL    #Defeat R's pathological evaluation rules
+  x<-.Call("addEdge_R",x,tail,head,names.eval,vals.eval,edge.check, PACKAGE="network")
+  if(exists(xn,envir=ev))            #If x not anonymous, set in calling env
+    on.exit(assign(xn,x,pos=ev))
+  invisible(x)
 }
 
 
@@ -94,7 +100,13 @@ add.edges<-function(x, tail, head, names.eval=NULL, vals.eval=NULL, ...){
   if(is.null(edge.check))
     edge.check<-FALSE
   #Pass the inputs to the C side
-  invisible(.Call("addEdges_R",x,tail,head,names.eval,vals.eval,edge.check, PACKAGE="network"))
+  xn<-deparse(substitute(x))
+  ev<-parent.frame()
+  x$RIsTooLazy<-NULL    #Defeat R's pathological evaluation rules
+  x<-.Call("addEdges_R",x,tail,head,names.eval,vals.eval,edge.check, PACKAGE="network")
+  if(exists(xn,envir=ev))            #If x not anonymous, set in calling env
+    on.exit(assign(xn,x,pos=ev))
+  invisible(x)
 }
 
 
@@ -114,15 +126,23 @@ add.vertices<-function(x, nv, vattr=NULL, last.mode=TRUE){
       vattr<-as.list(rep(vattr,length=nv))
   }
   #Perform the addition
+  xn<-deparse(substitute(x))
+  ev<-parent.frame()
   if(nv>0){
-    if(last.mode||(!is.bipartite(x)))
-      invisible(.Call("addVertices_R",x,nv,vattr, PACKAGE="network"))
-    else{
+    x$RIsTooLazy<-NULL    #Defeat R's pathological evaluation rules
+    if(last.mode||(!is.bipartite(x))){
+      x<-.Call("addVertices_R",x,nv,vattr, PACKAGE="network")
+      if(exists(xn,envir=ev))           #If x not anonymous, set in calling env
+        on.exit(assign(xn,x,pos=ev))
+      invisible(x)
+    }else{
       .Call("addVertices_R",x,nv,vattr, PACKAGE="network")
       newid<-c(1:(x%n%"bipartite"),network.size(x),
         ((x%n%"bipartite"+1)):(network.size(x)-1))
-      permute.vertexIDs(x,vid=newid)
+      permute.vertexIDs(x,vids=newid)
       x%n%"bipartite"<-x%n%"bipartite"+1
+      if(exists(xn,envir=ev))           #If x not anonymous, set in calling env
+        on.exit(assign(xn,x,pos=ev))
       invisible(x)
     }
   }else
@@ -137,7 +157,13 @@ delete.edge.attribute<-function(x,attrname){
   if(!is.network(x))
     stop("delete.edge.attribute requires an argument of class network.")
   #Remove the edges
-  invisible(.Call("deleteEdgeAttribute_R",x,attrname, PACKAGE="network"))
+  xn<-deparse(substitute(x))
+  ev<-parent.frame()
+  x$RIsTooLazy<-NULL    #Defeat R's pathological evaluation rules
+  x<-.Call("deleteEdgeAttribute_R",x,attrname, PACKAGE="network")
+  if(exists(xn,envir=ev))          #If x not anonymous, set in calling env
+    on.exit(assign(xn,x,pos=ev))
+  invisible(x)
 }
  
  
@@ -147,12 +173,18 @@ delete.edges<-function(x,eid){
   #Check to be sure we were called with a network
   if(!is.network(x))
     stop("delete.edges requires an argument of class network.")
+  xn<-deparse(substitute(x))
+  ev<-parent.frame()
   if(length(eid)>0){
     #Perform a sanity check
     if((min(eid)<1)|(max(eid)>length(x$mel)))
       stop("Illegal edge in delete.edges.\n")
     #Remove the edges
-    invisible(.Call("deleteEdges_R",x,eid, PACKAGE="network"))
+    x$RIsTooLazy<-NULL    #Defeat R's pathological evaluation rules
+    x<-.Call("deleteEdges_R",x,eid, PACKAGE="network")
+    if(exists(xn,envir=ev))          #If x not anonymous, set in calling env
+      on.exit(assign(xn,x,pos=ev))
+    invisible(x)
   }else
     invisible(x)
 }
@@ -165,7 +197,13 @@ delete.network.attribute<-function(x,attrname){
   if(!is.network(x))
     stop("delete.network.attribute requires an argument of class network.")
   #Remove the edges
-  invisible(.Call("deleteNetworkAttribute_R",x,attrname, PACKAGE="network"))
+  xn<-deparse(substitute(x))
+  ev<-parent.frame()
+  x$RIsTooLazy<-NULL    #Defeat R's pathological evaluation rules
+  x<-.Call("deleteNetworkAttribute_R",x,attrname, PACKAGE="network")
+  if(exists(xn,envir=ev))          #If x not anonymous, set in calling env
+    on.exit(assign(xn,x,pos=ev))
+  invisible(x)
 }
 
 
@@ -179,8 +217,14 @@ delete.vertex.attribute<-function(x,attrname){
   #Check to be sure we were called with a network
   if(!is.network(x))
     stop("delete.vertex.attribute requires an argument of class network.")
-  #Remove the edges
-  invisible(.Call("deleteVertexAttribute_R",x,attrname, PACKAGE="network"))
+  #Remove the attribute
+  xn<-deparse(substitute(x))
+  ev<-parent.frame()
+  x$RIsTooLazy<-NULL    #Defeat R's pathological evaluation rules
+  x<-.Call("deleteVertexAttribute_R",x,attrname, PACKAGE="network")
+  if(exists(xn,envir=ev))          #If x not anonymous, set in calling env
+    on.exit(assign(xn,x,pos=ev))
+  invisible(x)
 }
 
 
@@ -193,12 +237,18 @@ delete.vertices<-function(x,vid){
   #Remove any vids which are out of bounds
   vid<-vid[(vid>0)&(vid<=network.size(x))]
   #Do the deed, if still needed
+  xn<-deparse(substitute(x))
+  ev<-parent.frame()
   if(length(vid)>0){
+    x$RIsTooLazy<-NULL    #Defeat R's pathological evaluation rules
     if(is.bipartite(x)){  #If bipartite, might need to adjust mode 1 count
       m1v<-get.network.attribute(x,"bipartite")  #How many mode 1 verts?
       set.network.attribute(x,"bipartite",m1v-sum(vid<=m1v))
     }
-    invisible(.Call("deleteVertices_R",x,vid, PACKAGE="network"))
+    x<-.Call("deleteVertices_R",x,vid, PACKAGE="network")
+    if(exists(xn,envir=ev))
+      on.exit(assign(xn,x,pos=ev))
+    invisible(x)
   }else
     invisible(x)
 }
@@ -610,7 +660,13 @@ permute.vertexIDs<-function(x,vids){
       warning("Performing a cross-mode permutation in permute.vertexIDs.  I hope you know what you're doing....")
   }
   #Return the permuted graph
-  invisible(.Call("permuteVertexIDs_R",x,vids, PACKAGE="network"))
+  xn<-deparse(substitute(x))
+  ev<-parent.frame()
+  x$RIsTooLazy<-NULL    #Defeat R's pathological evaluation rules
+  x<-.Call("permuteVertexIDs_R",x,vids, PACKAGE="network")
+  if(exists(xn,envir=ev))          #If x not anonymous, set in calling env
+    on.exit(assign(xn,x,pos=ev))
+  invisible(x)
 }
 
 
@@ -629,11 +685,17 @@ set.edge.attribute<-function(x,attrname,value,e=1:length(x$mel)){
   }else
     if(length(value)!=length(e))
       value<-rep(value,length=length(e))
+  xn<-deparse(substitute(x))
+  ev<-parent.frame()
   if(length(e)>0){
     if((min(e)<1)|(max(e)>length(x$mel)))
       stop("Illegal edge in set.edge.attribute.\n")
     #Do the deed
-    invisible(.Call("setEdgeAttribute_R",x,attrname,value,e, PACKAGE="network"))
+    x$RIsTooLazy<-NULL    #Defeat R's pathological evaluation rules
+    x<-.Call("setEdgeAttribute_R",x,attrname,value,e, PACKAGE="network")
+    if(exists(xn,envir=ev))          #If x not anonymous, set in calling env
+      on.exit(assign(xn,x,pos=ev))
+    invisible(x)
   }else
     invisible(x)
 }
@@ -660,7 +722,13 @@ set.edge.value<-function(x,attrname,value,e=1:length(x$mel)){
   if((min(e)<1)|(max(e)>length(x$mel)))
     stop("Illegal edge in set.edge.value.\n")
   #Do the deed
-  invisible(.Call("setEdgeValue_R",x,attrname,value,e, PACKAGE="network"))
+  xn<-deparse(substitute(x))
+  ev<-parent.frame()
+  x$RIsTooLazy<-NULL    #Defeat R's pathological evaluation rules
+  x<-.Call("setEdgeValue_R",x,attrname,value,e, PACKAGE="network")
+  if(exists(xn,envir=ev))          #If x not anonymous, set in calling env
+    on.exit(assign(xn,x,pos=ev))
+  invisible(x)
 }
 
 
@@ -686,7 +754,13 @@ set.network.attribute<-function(x,attrname,value){
       stop("Non-replicable value with multiple attribute names in set.network.attribute.\n")
   }
   #Do the deed
-  invisible(.Call("setNetworkAttribute_R",x,attrname,value,PACKAGE="network"))
+  xn<-deparse(substitute(x))
+  ev<-parent.frame()
+  x$RIsTooLazy<-NULL    #Defeat R's pathological evaluation rules
+  x<-.Call("setNetworkAttribute_R",x,attrname,value,PACKAGE="network")
+  if(exists(xn,envir=ev))          #If x not anonymous, set in calling env
+    on.exit(assign(xn,x,pos=ev))
+  invisible(x)
 }
 
 
@@ -709,6 +783,12 @@ set.vertex.attribute<-function(x,attrname,value,v=1:network.size(x)){
     if(length(value)!=length(v))
       value<-rep(value,length=length(v))
   #Do the deed
-  invisible(.Call("setVertexAttribute_R",x,attrname,value,v, PACKAGE="network"))
+  xn<-deparse(substitute(x))
+  ev<-parent.frame()
+  x$RIsTooLazy<-NULL    #Defeat R's pathological evaluation rules
+  x<-.Call("setVertexAttribute_R",x,attrname,value,v, PACKAGE="network")
+  if(exists(xn,envir=ev))          #If x not anonymous, set in calling env
+    on.exit(assign(xn,x,pos=ev))
+  invisible(x)
 }
 
